@@ -100,7 +100,7 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
     mainLayout->addWidget(dlgButtonBoxBottom);
 
     // read the size here...
-    KConfigGroup window(KSharedConfig::openStateConfig(), "Window");
+    KConfigGroup window(KSharedConfig::openStateConfig(), QStringLiteral("Window"));
     QSize rect = window.readEntry("Geometry", QSize(740, 400));
     resize(rect);
 
@@ -226,10 +226,10 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
     // prepare the Show Image Dialog
     m_showImgDialog = new ShowImageDialog(this);
     connect(m_showImgDialog, &ShowImageDialog::saveRequested, this, &Skanlite::saveImage);
-    connect(m_showImgDialog, &ShowImageDialog::rejected, m_ksanew, &KSaneWidget::scanCancel);
+    connect(m_showImgDialog, &ShowImageDialog::rejected, m_ksanew, &KSaneWidget::cancelScan);
 
     // save the default sane options for later use
-    m_ksanew->getOptVals(m_defaultScanOpts);
+    m_ksanew->getOptionValues(m_defaultScanOpts);
 
     // load saved options
     loadScannerOptions();
@@ -239,9 +239,9 @@ Skanlite::Skanlite(const QString &device, QWidget *parent)
 
     if (m_dbusInterface.setupDBusInterface()) {
         // D-Bus related slots
-        connect(&m_dbusInterface, &DBusInterface::requestedScan, m_ksanew, &KSaneWidget::scanFinal);
+        connect(&m_dbusInterface, &DBusInterface::requestedScan, m_ksanew, &KSaneWidget::startScan);
         connect(&m_dbusInterface, &DBusInterface::requestedPreview, m_ksanew, &KSaneWidget::startPreviewScan);
-        connect(&m_dbusInterface, &DBusInterface::requestedScanCancel, m_ksanew, &KSaneWidget::scanCancel);
+        connect(&m_dbusInterface, &DBusInterface::requestedScanCancel, m_ksanew, &KSaneWidget::cancelScan);
         connect(&m_dbusInterface, &DBusInterface::requestedSetScannerOptions, this, &Skanlite::setScannerOptions);
         connect(&m_dbusInterface, &DBusInterface::requestedSetSelection, this, &Skanlite::setSelection);
 
@@ -279,14 +279,14 @@ void Skanlite::closeEvent(QCloseEvent *event)
 
 void Skanlite::saveWindowSize()
 {
-    KConfigGroup window(KSharedConfig::openStateConfig(), "Window");
+    KConfigGroup window(KSharedConfig::openStateConfig(), QStringLiteral("Window"));
     window.writeEntry("Geometry", size());
     window.sync();
 }
 
 void Skanlite::saveScannerDevice()
 {
-    KConfigGroup general(KSharedConfig::openStateConfig(), "General");
+    KConfigGroup general(KSharedConfig::openStateConfig(), QStringLiteral("General"));
     general.writeEntry(QStringLiteral("deviceName"), m_deviceName);
     general.writeEntry(QStringLiteral("deviceModel"), m_deviceModel);
     general.writeEntry(QStringLiteral("deviceVendor"), m_deviceVendor);
@@ -332,7 +332,7 @@ void Skanlite::readSettings(void)
     m_settingsUi.setPreviewDPI->setChecked(true);
 
     // read the saved parameters
-    KConfigGroup saving(KSharedConfig::openConfig(), "Image Saving");
+    KConfigGroup saving(KSharedConfig::openConfig(), QStringLiteral("Image Saving"));
     m_settingsUi.saveModeCB->setCurrentIndex(saving.readEntry("SaveMode", (int)SaveModeManual));
     if (m_settingsUi.saveModeCB->currentIndex() != SaveModeAskFirst) {
         m_firstImage = false;
@@ -349,7 +349,7 @@ void Skanlite::readSettings(void)
     m_settingsUi.setQuality->setChecked(saving.readEntry("SetQuality", false));
     m_settingsUi.showB4Save->setChecked(saving.readEntry("ShowBeforeSave", true));
 
-    KConfigGroup general(KSharedConfig::openConfig(), "General");
+    KConfigGroup general(KSharedConfig::openConfig(), QStringLiteral("General"));
 
     //m_settingsUi.previewDPI->setCurrentItem(general.readEntry("PreviewDPI", "100"), true); // FIXME KF5 is the 'true' parameter still needed?
     m_settingsUi.previewDPI->setCurrentText(general.readEntry("PreviewDPI", "100"));
@@ -372,7 +372,7 @@ void Skanlite::showSettingsDialog(void)
     // show the dialog
     if (m_settingsDialog->exec()) {
         // save the settings
-        KConfigGroup saving(KSharedConfig::openConfig(), "Image Saving");
+        KConfigGroup saving(KSharedConfig::openConfig(), QStringLiteral("Image Saving"));
         saving.writeEntry("SaveMode", m_settingsUi.saveModeCB->currentIndex());
         saving.writeEntry("Location", m_settingsUi.saveDirRequester->url());
         saving.writeEntry("NamePrefix", m_settingsUi.imgPrefix->text());
@@ -382,7 +382,7 @@ void Skanlite::showSettingsDialog(void)
         saving.writeEntry("ShowBeforeSave", m_settingsUi.showB4Save->isChecked());
         saving.sync();
 
-        KConfigGroup general(KSharedConfig::openConfig(), "General");
+        KConfigGroup general(KSharedConfig::openConfig(), QStringLiteral("General"));
         general.writeEntry("PreviewDPI", m_settingsUi.previewDPI->currentText());
         general.writeEntry("SetPreviewDPI", m_settingsUi.setPreviewDPI->isChecked());
         general.writeEntry("DisableAutoSelection", m_settingsUi.u_disableSelections->isChecked());
@@ -458,7 +458,7 @@ void Skanlite::saveImage()
         while (m_firstImage || !dirExists) {
             m_saveLocation->setOpenRequesterOnShow(!dirExists);
             if (m_saveLocation->exec() != QFileDialog::Accepted) {
-                m_ksanew->scanCancel(); // In case we are cancelling a document feeder scan
+                m_ksanew->cancelScan(); // In case we are cancelling a document feeder scan
                 return;
             }
             dirUrl = m_saveLocation->folderUrl();
@@ -659,7 +659,7 @@ void readScannerOptions(const QString &groupName, QMap <QString, QString> &opts)
 
 void Skanlite::saveScannerOptions()
 {
-    KConfigGroup saving(KSharedConfig::openConfig(), "Image Saving");
+    KConfigGroup saving(KSharedConfig::openConfig(), QStringLiteral("Image Saving"));
     saving.writeEntry("NumberStartsFrom", m_saveLocation->startNumber());
 
     if (!m_ksanew) {
@@ -669,7 +669,7 @@ void Skanlite::saveScannerOptions()
     if (!m_deviceName.isEmpty()) {
         KConfigGroup options(KSharedConfig::openStateConfig(), QStringLiteral("Options For %1").arg(m_deviceName));
         QMap <QString, QString> opts;
-        m_ksanew->getOptVals(opts);
+        m_ksanew->getOptionValues(opts);
         writeScannerOptions(QStringLiteral("Options For %1").arg(m_deviceName), opts);
     }
 }
@@ -685,7 +685,7 @@ void Skanlite::defaultScannerOptions()
 
 void Skanlite::applyScannerOptions(const QMap <QString, QString> &opts)
 {
-    if (m_ksanew->setOptVals(opts) == -1) {
+    if (m_ksanew->setOptionValues(opts) == -1) {
         m_pendingApplyScanOpts = opts;
     } else {
         m_pendingApplyScanOpts.clear();
@@ -695,7 +695,7 @@ void Skanlite::applyScannerOptions(const QMap <QString, QString> &opts)
 void Skanlite::loadScannerOptions()
 {
     if (!m_deviceName.isEmpty()) {
-        KConfigGroup saving(KSharedConfig::openConfig(), "Image Saving");
+        KConfigGroup saving(KSharedConfig::openConfig(), QStringLiteral("Image Saving"));
         m_saveLocation->setStartNumber(saving.readEntry("NumberStartsFrom", 1));
 
         if (!m_ksanew) {
@@ -794,7 +794,7 @@ void Skanlite::getScannerOptions()
 {
     if (!m_deviceName.isEmpty()) {
         QMap <QString, QString> opts;
-        m_ksanew->getOptVals(opts);
+        m_ksanew->getOptionValues(opts);
         m_dbusInterface.setReply(serializeScannerOptions(opts));
     }
 }
@@ -853,7 +853,7 @@ void Skanlite::getSelection()
 {
     if (!m_deviceName.isEmpty()) {
         QMap <QString, QString> opts;
-        m_ksanew->getOptVals(opts);
+        m_ksanew->getOptionValues(opts);
 
         QStringList reply;
         for (const auto &key : selectionSettings ) {
